@@ -1,12 +1,10 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback;
-BEGIN {
-  $Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v0.004-2-g354b25b
-$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.005';
+# git description: v0.005-11-gdcebf3a
+$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.006';
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
+# KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sw=4 tw=78 et :
 
 use Moose;
@@ -40,7 +38,7 @@ has plugins => (
     default => sub {
         my $self = shift;
         my @plugins = @{ $self->zilla->plugins };
-        my %args = ( plugin_name => 'ModuleBuildTiny::Fallback', zilla => $self->zilla );
+        my %args = ( plugin_name => 'ModuleBuildTiny::Fallback', zilla => $self->zilla, default_jobs => $self->default_jobs );
         [
             Dist::Zilla::Plugin::ModuleBuild->new(%args, mb_version => $self->mb_version),
             Dist::Zilla::Plugin::ModuleBuildTiny->new(%args, $self->mbt_version ? ( version => $self->mbt_version ) : ()),
@@ -50,6 +48,28 @@ has plugins => (
     handles => { plugins => 'elements' },
 );
 
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        plugins => [
+            map {
+                my $plugin = $_;
+                my $config = $plugin->dump_config;
+                +{
+                    class   => $plugin->meta->name,
+                    name    => $plugin->plugin_name,
+                    version => $plugin->VERSION,
+                    (keys %$config ? (config => $config) : ()),
+                }
+            } $self->plugins
+        ],
+    };
+
+    return $config;
+};
 sub before_build
 {
     my $self = shift;
@@ -114,7 +134,7 @@ sub setup_installer
     $mb_content =~ s/^use (Module::Build) ([\d.]+);/require $1; $1->VERSION($2);/m;
     $mb_content =~ s/^(?!$)/    /mg;
 
-    # now let [ModuleBuildTiny] create (oor update) the Build.PL file and its content
+    # now let [ModuleBuildTiny] create (or update) the Build.PL file and its content
     if (my $file = $files{'Dist::Zilla::Plugin::ModuleBuildTiny'}) { push @{ $self->zilla->files }, $file }
     $self->log_debug('generating Build.PL content from [ModuleBuildTiny]');
     $mbt->setup_installer;
@@ -135,6 +155,9 @@ sub setup_installer
         <<"FALLBACK",
 # This Build.PL for ${\ $self->zilla->name } was generated by
 # ${\ ref $self } ${ \($self->VERSION || '<self>') }
+use strict;
+use warnings;
+
 if (eval 'use Module::Build::Tiny $mbt_version; 1')
 {
     print "Congratulations, your toolchain understands 'configure_requires'!\\n\\n";
@@ -257,14 +280,11 @@ __PACKAGE__->meta->make_immutable;
 #pod
 #pod =head1 SEE ALSO
 #pod
-#pod =begin :list
-#pod
+#pod =for :list
 #pod * L<Dist::Zilla::Plugin::MakeMaker::Fallback> (which can happily run alongside this plugin)
 #pod * L<Dist::Zilla::Plugin::ModuleBuildTiny>
 #pod * L<Dist::Zilla::Plugin::ModuleBuild>
 #pod
-#pod =end :list
-#pod
 #pod =cut
 
 =pod
@@ -277,7 +297,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
